pysmad.propagators
=====================

.. toctree::
   :maxdepth: 2

   pysmad.propagators.inertial
   pysmad.propagators.relative

.. automodule:: pysmad.propagators
   :members:
   :undoc-members:
   :show-inheritance:
